**Example 1: 创建从实例**



Input: 

```
tccli tcr CreateReplicationInstance --cli-unfold-argument  \
    --RegistryId tcr-12345 \
    --ReplicationRegionId 5
```

Output: 
```
{
    "Response": {
        "RequestId": "c8bf292d-38c7-49d9-8da3-737d08160cfc",
        "ReplicationRegistryId": "tcr-06d62e1r-5"
    }
}
```

